/*
    GNOME Commander - A GNOME based file manager 
    Copyright (C) 2001-2003 Marcus Bjurman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 
#ifndef __DIR_POOL_H__
#define __DIR_POOL_H__

#include "gnome-cmd-dir-types.h"

void         dir_pool_init (void);
GnomeCmdDir *dir_pool_get (const gchar *dir_uri_str);
void         dir_pool_add (GnomeCmdDir *dir);
void         dir_pool_remove (GnomeCmdDir *dir);
gboolean     dir_pool_exists (GnomeCmdDir *dir);
void         dir_pool_show_state (void);

#endif //__DIR_POOL_H__
